from multipledispatch import dispatch

class Stack():

    def __init__(self, size, elements):
        self.size = size
        self.elements = elements
        self.length = len(elements)
    
    def index(self, position):
        return self.elements[position]

    def add(self, element):
        if(self.size == len(self.elements)):
            print("Stack is full")
        else:
            self.elements.append(element)
            self.length += 1

    def remove(self):
        if(len(self.elements) == 0):
            print("Stack is empty")
        else:
            elementToReturn = self.elements.pop()
            self.length -= 1
            return elementToReturn
            
    def display(self):
        print(self.elements)

    def getElements(self):
        return self.elements
    
    def getSize(self):
        return self.size

    def getLength(self):
        return self.length


def stack(size):

    if(isinstance(size, int)):
        elements = [0] * size
        return Stack(size, elements)

    elif(isinstance(size, list)):
        elements = size
        size = len(elements)
        return Stack(size, elements)


from setuptools import setup, find_packages

classifiers=[
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
]

setup(
    name = 'easydsi',
    version = '1.0.1',
    description = 'The library which helps users to implement data structres & algoithms easily without implementing each and every structure.',
    long_description = open('README.md').read() + '\n\n' + open('CHANGELOG.txt').read(),
    long_description_content_type = 'text/markdown',
    url = 'https://github.com/fazil2003/easydsi',
    author = 'Mohamed Fazil',
    author_email = 'mohamedfazil463@gmail.com',
    license = 'MIT',
    classifiers = classifiers,
    keywords = 'data-structures, algorithms, data, structures, data structures, data structure',
    packages = find_packages(),
    install_requires = ['multipledispatch==0.6.0']
)
